#!/usr/bin/perl
################################################################################
# eWLA (e Web Log Analyzer)                         Version 0.1                #
# Copyright 2000 Frederic TYNDIUK (FTLS)            All Rights Reserved.       #
# E-Mail: tyndiuk@ftls.org                          Script License: GPL        #
# Created  05/31/00                                 Last Modified 05/25/00     #
# Scripts Archive at:                               http://www.ftls.org/cgi/   #
################################################################################
# Creates multi-page HTML reports of Apache log statistics.                    #
#   Libs.                                                                      #
################################################################################
my $COPYRIGHT  = "eWLA v0.1 (C) 2000 Frederic TYNDIUK (alias FTLS)\n";
   $COPYRIGHT .= "Report bugs to tyndiuk\@ftls.org, News and Updates: http://www.ftls.org/\n\n";

sub read_args {
	my %params = @_;
	while ($ARGV[0] =~ /^-/) {
		if (($ARGV[0] eq "-c")   || ($ARGV[0] eq "--conf-file")) { shift(@ARGV); if($ARGV[0]) { $params{'ConfigFile'} = $ARGV[0];} }
		if (($ARGV[0] eq "-l")   || ($ARGV[0] eq "--log-file"))  { shift(@ARGV); if($ARGV[0]) { $params{'LogFile'} = $ARGV[0];} }
		if (($ARGV[0] eq "-rd")  || ($ARGV[0] eq "--res-dir"))   { shift(@ARGV); if($ARGV[0]) { $params{'ResumeDir'} = $ARGV[0];} }
		if (($ARGV[0] eq "-od")  || ($ARGV[0] eq "--out-dir"))   { shift(@ARGV); if($ARGV[0]) { $params{'OutputDir'} = $ARGV[0];} }
		if (($ARGV[0] eq "-sn")  || ($ARGV[0] eq "--server-name"))   { shift(@ARGV); if($ARGV[0]) { $params{'ServerName'} = $ARGV[0];} }
		if (($ARGV[0] eq "-su")  || ($ARGV[0] eq "--server-url"))   { shift(@ARGV); if($ARGV[0]) { $params{'ServerURL'} = $ARGV[0];} }
		if (($ARGV[0] eq "-hn")  || ($ARGV[0] eq "--host-name"))   { shift(@ARGV); if($ARGV[0]) { $params{'HostNames'} = $ARGV[0];} }
		if (($ARGV[0] eq "-v")   || ($ARGV[0] eq "--version"))   { print $COPYRIGHT; exit; }
		if (($ARGV[0] eq "-h")   || ($ARGV[0] eq "--help"))      { &usage(); }
		shift(@ARGV);
	}
	return %params;
}


sub load_data_from_config_file {
	my %params = @_;
	open (CONFIG, "<$params{'ConfigFile'}") || die "Error opening config file: $params{'ConfigFile'}, error: $!\n";
	foreach (<CONFIG>) {
		if ((! /^\s*#/) && (/\w/)) {
			s/'//g;
			/([^= ]+)\s+=\s+(.*)\s*\n/;
			my $id = $1;
			my $param = $2;
			$param =~ s/^\s+|\s+$//;
			if ($param eq 'yes') { $param = 1; }
			if ($param eq 'no') { $param = 0; }
			if (! $params{$id}) { $params{$id} = $param };
		}
	}
	close(CONFIG);
	return %params;
}

sub usage {
	print STDERR $COPYRIGHT;
	print STDERR <<EOF;
Usage: $0 [Options]
or: perl $0 [Options]
Options:
  -c file,   --conf-file file   config file name.
  -l file,   --log-file file    log file name.
  -rd dir    --res-dir dir      name resume dir.
  -od dir    --out-dir dir      name output dir.
  -sn name   --server-name      name (title) of server - ex: FTLS.org web site
  -sn url    --server-url       url of server - ex: http://www.ftls.org/
  -hn name   --host-name        name(s) virtuals hosts - ex: (ftls\.org|ftls\.net)
  -v,        --version          output version information and exit.
  -h,        --help             display this help and exit.
EOF
	exit 1;
}


#####################
# Litle Common Subs #
#####################

sub repace_into_template_file {
	my ($file_name, %data) = @_;
	open(COM, "$file_name") || die("Cannot open 'template file' ($file_name), error: $!",1);
	my $data = join('', <COM>);
	close(COM);
	return &replace_into_template($data, %data);
}

sub replace_into_template {
	my($page, %data) = @_;
	my($key);
	foreach $key ( keys (%data) ) {
		$page =~ s/([^\w])Value_$key([^\w])/$1$data{$key}$2/gi;
	}
	$page =~ s/Value_\w+([^\w])/$1/gi;
	return $page;
}

sub load_txt_file {                                                            
	my($file_name, $error_txt) = @_;
	open(LOAD, "<$file_name") || die("Cannot open $error_txt ($file_name), error: $!");
	my @data = <LOAD>;
	close(LOAD);
	return @data;
}

sub save_txt_file {
	my ($file_name, $error_txt, $txt) = @_;
	open(SAVE, ">$file_name") || die("Cannot write $error_txt ($file_name), Error $!");
	print SAVE $txt;
	close(SAVE);
}

1;